<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\ThirdPlatform\Api;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\ThirdPlatform\PlatformAbstractService;
use App\Support\Facades\SimpleLogs;
use App\Support\Traits\HttpClientHelpers;


class LeyanApiService extends PlatformAbstractService
{
    use HttpClientHelpers;

    public function __construct(ThirdApiPlatformRepository $thirdApiPlatformRepository)
    {
        parent::__construct($thirdApiPlatformRepository);
        $this->setPlatformName('leyan');
        $this->getPlatformInfo();
    }

    /**
     * 批量更新商品信息
     * @param $product
     * @return bool
     */
    public function pushUpdateProductByCas($product,$token)
    {
        try{
            if($this->checkplatformstatus()){
                $params = [];
                $params['casNo'] = $this->mergeapimetadata($product);

                $uri = $this->platformInfo['platform_url'].'/ProductDate/findProductDataPoolByCatalogNoOrCas';
                $response = $this->getpostclient(
                    $uri, $params,null,
                    [
                        'token' => $token,
                        'content-type' => 'application/json;charset=utf-8'
                    ]
                );

                return $this->apiresponse($response);
            }
        }catch(\exception $exception){
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':pushUpdateProductByCas error', 'error');
            return false;
        }
    }

    public function pushBatchUpdateProduct($token){

    }

    public function getToken(){
        try{
            if($this->checkPlatformStatus()){
                $tokenParams = [
                    'username' => $this->platformInfo['platform_params']['username'],
                    'password' => $this->platformInfo['platform_params']['password']
                ];
                $response = $this->getPostClient($this->platformInfo['platform_url'].'/ProductDate/getToken',[],null,
                    [
                         $tokenParams,
                        'content-type' => 'application/json;charset=utf-8'
                    ]
                );
                $token = $this->apiResponse($response);

                return $token['data'];
            }

        }catch(\Exception $exception){
            SimpleLogs::writeLog($exception->getMessage(), __CLASS__.':token error', 'error');
            return false;
        }
    }

    /**
     * 整理组装 api 数据
     * @param $metaData
     * @return array
     */
    public function mergeApiMetaData($metaData)
    {
        return $metaData;
    }

    protected function apiResponse($response)
    {
        $decodeResponse = json_decode($response,true);
        if($decodeResponse['status'] == '1' && $decodeResponse['code'] == '0'){
            if(!empty($decodeResponse['data'])){
                return $decodeResponse['data'];
            }
        }elseif($decodeResponse['status'] == '0'){
            if(!is_array($decodeResponse['data'])){
                return false;
            }
        }
        return false;
    }
}
